/********************************************************/
/*                       gutil.c                        */
/* ---------------------------------------------------- */
/* Guig                                         Oct. 95 */
/********************************************************/
/*
 * CVS log:
 *
 * $Author: gravier $
 * $Date $
 * $Revision: 1.3 $
 *
 */
/*
 * My habits for argument processing and all other lazy
 * tricks.
 */

#define _gutil_c_

#include <gutil.h>
#include <gerror.h>

/*****
 * argument processing global private definitions
*****/
int gutil_argcur;      /* Current arg index in argv array */
int gutil_argcount;    /* internal argc                   */
char **gutil_argval;   /* internal array                  */
static swtab_t *gutil_swtab=(swtab_t *)NULL;  /* internal long option table      */
int eq=0;

/* ----------------------------------------------- */
/* ----- bool_t bfscan(FILE *,char *,void *) ----- */
/* ----------------------------------------------- */
bool_t bfscan(FILE *f,char *fmt,void *v)
{
  int c;
  
  if((c=getc(f)) == CR)
    return(false);
  (void) ungetc(c,f);
  fscanf(f,fmt,v);
  c=getc(f);
  return(true);
}

/* ----------------------------------------- */
/* ----- bool_t getline(FILE *,char *) ----- */
/* ----------------------------------------- */
bool_t getline(FILE *f,char *str)
{
  int c;
  int i=0;

  while((c=getc(f)) != '\n' )
    if(c == EOF)
      if(i == 0)
	return(false);
      else
	ungetc(c,f);
    else
      str[i++]=(char)c;
  str[i]='\0';
  return(true);
}

/********** MULTIPLE FILE CLOSURE **********/
/* ---------------------------------- */
/* ----- void fover(FILE *,...) ----- */
/* ---------------------------------- */
void fover(FILE *f, ... )
{
  va_list p;
  FILE *next;

  va_start(p,f);
  fclose(f);
  while((next=va_arg(p,FILE *)) != NULL)
    fclose(next);
  va_end(p);
}

/* -------------------------------------- */
/* ----- void ArgInit(int ,char **) ----- */
/* -------------------------------------- */
/*
Initialises the internal global variables
*/
void ArgInit(int n, char **a)
{
  gutil_argcur=1;
  gutil_argcount=n;
  gutil_argval=a;
  prog=(prog=strrchr(gutil_argval[0],'/')) == NULL?gutil_argval[0]:prog+1;
}

/* ------------------------------------------ */
/* ----- void LongArgInit(int ,char **) ----- */
/* ------------------------------------------ */
/*
Initialises the internal global variables
*/
void LongArgInit(int n,char **a,swtab_t *swtab)
{
  gutil_argcur=1;
  gutil_argcount=n;
  gutil_argval=a;
  gutil_swtab=swtab;
  prog=(prog=strrchr(gutil_argval[0],'/')) == NULL?gutil_argval[0]:prog+1;
}
/* ------------------------------------ */
/* ----- bool_t IsNumArg(char *s) ----- */
/* ------------------------------------ */
/*
  returns true if str is a numerical argument, false otherwise
*/
bool_t IsNumArg(char *str)
{
  int i=1;
  bool_t fpt=false;

  if(!str)
    return(false);
  if(str[0]=='.')
    fpt=true;
  else
    if(str[0]!='-' && !isdigit(str[0]))
      return(false);
  while(str[i]!='\0')
    {
      if(str[i]=='.')
        if(fpt)
	  return(false);
	else
	  fpt=true;
      else
	if(!isdigit(str[i]))
	  return(false);
      i++;
    }
  return(true);
}

/* ----------------------------------- */
/* ----- bool_t IsSwtArg(char *) ----- */
/* ----------------------------------- */
/*
  True if s is a switch -<aLetter>
*/
bool_t IsSwtArg(char *s)
{
  if(s[0]=='-' && isalpha(s[1]) && s[2]=='\0')
    return(true);
  return(false);
}

/* --------------------------------------- */
/* ----- bool_t IsLongSwtArg(char *) ----- */
/* --------------------------------------- */
/*
  True if s is a switch --{aLetter}*
*/
bool_t IsLongSwtArg(char *s)
{
  if(s[0] == '-' && s[1] == '-' && isalpha(s[2]))
    return(true);
  return(false);
}

/* --------------------------------- */
/* ----- char* GetStrArg(void) ----- */
/* --------------------------------- */
/* returns a pointer to current argument */
char* GetStrArg(void)           
{
  if( gutil_argcur >= gutil_argcount )
    return(NULL);
  gutil_argcur++;
  return(gutil_argval[gutil_argcur-1]);
}

/* -------------------------------- */
/* ----- char GetSwitch(void) ----- */
/* -------------------------------- */
/* returns the switch character */
char GetSwitch(void)            
{
  char c;

  if(gutil_argcur >= gutil_argcount)
    return(NOSWT);
  if(!IsSwtArg(gutil_argval[gutil_argcur])) {
    if(gutil_swtab) {
      if(!IsLongSwtArg(gutil_argval[gutil_argcur]))
	return(NOSWT);
      else if((c=GetLongSwitch(gutil_argval[gutil_argcur])) == BAD_LONG_SWT_ARG) {
	gerror(ARGS_ERR,"GetSwitch(): invalid long option %s",gutil_argval[gutil_argcur]);
	return(BAD_LONG_SWT_ARG);
      }
    }
    else
      return(NOSWT);
  }
  else c=gutil_argval[gutil_argcur][1];
  gutil_argcur++;
  return(c);
}

/* --------------------------------- */
/* ----- float GetNumArg(void) ----- */
/* --------------------------------- */
float GetNumArg(void)           /* returns a float */
{
  if( gutil_argcur >=  gutil_argcount )
    return(0.0);
  gutil_argcur++;
  return((float)atof(gutil_argval[gutil_argcur-1]));
}

/* -------------------------------------- */
/* ----- unsigned NextArgType(void) ----- */
/* -------------------------------------- */
unsigned NextArgType(void)
{
  if( gutil_argcur >= gutil_argcount )
    return(NOARG);
  if( IsSwtArg(gutil_argval[gutil_argcur]) )
    return(SWTARG);
  if( IsNumArg(gutil_argval[gutil_argcur]) )
    return(NUMARG);
  return(STRARG);
}

/* -------------------------------------- */
/* ----- char GetLongSwitch(char *) ----- */
/* -------------------------------------- */
char GetLongSwitch(char *s)
{
  sindex_t i=0;

  while(gutil_swtab[i].longopt) {
    if(strcmp(gutil_swtab[i].longopt,s+2) == 0)
      return(gutil_swtab[i].swt);
    i++;
  }
  return(BAD_LONG_SWT_ARG);
}

/* ----------------------------------------- */
/* ----- char *progname(char *,char *) ----- */
/* ----------------------------------------- */
char *progname(char *base,char *name)
{
  char *tmp;
  size_t n;
  
  tmp=(tmp=strrchr(name,'/'))==NULL?name:tmp+1;
  n=strcspn(tmp,".");
  strncpy(base,tmp,n);
  base[n]='\0';
  return(base);
}

/* ----------------------------- */
/* ----- long fsize(FILE *) ----- */
/* ----------------------------- */
/*
 * Returns file size in bytes
 */
long fsize(FILE *f)
{
  long pos=ftell(f);
  long size;

  fseek(f,0L,SEEK_END);
  size=ftell(f);
  fseek(f,pos,SEEK_SET);
  return(size);
}

#undef _gutil_c_

