#!/bin/sh
#########
#
# install libspro and related runtimes
#
# CVS log:
#
# $Author: gravier $
# $Date: 1999/12/03 13:35:21 $
# $Revision: 1.5 $
#

runtimes="slpc slpcep sfbank sfbcep slist scopy scepstrum"
libraries="libspro.a"
headers="spro.h sproerr.h"
resources=""

usage()
{
  echo "`basename $0` [-b bin-dir] root-dir"
  echo ""
  echo "    install runtimes in bin-dir (default: root-dir/bin/),"
  echo "    include files in root-dir/include and libspro.a in"
  echo "    root-dir/lib/"
  echo ""
  echo "headers= ${headers}"
  echo "libraries= ${libraries}"
  echo "runtimes= ${runtimes}"
#  echo "resources= ${resources}"
  echo ""
  exit 1
}

set -- `getopt hb: $*`
if [ $? -ne 0 ] ; then
  usage
fi
for opt in $* ; do
  case ${opt} in
    -b) bin_dir=$2; shift 2;;
    -h) usage;;
    --) shift; break;;
  esac
done

if [ $# -ne 1 ] ; then
  usage
fi

incl_dir=$1/include
lib_dir=$1/lib
# rsrc_dir=$1/rsrc
if [ -z "${bin_dir}" ] ; then
  bin_dir=$1/bin
fi

if [ ! -d "${incl_dir}" ] ; then
  echo "creating include directory ${incl_dir}"
  mkdir ${incl_dir}
fi
if [ ! -d "${lib_dir}" ] ; then
  echo "creating library directory ${lib_dir}"
  mkdir ${lib_dir}
fi
if [ ! -d "${bin_dir}" ] ; then
  echo "creating runtime directory ${bin_dir}"
  mkdir ${bin_dir}
fi

echo "Copying headers to directory ${incl_dir}"
for f in ${headers} ; do
  if [ -f "${f}" ] ; then
    echo "    ${f} -- ok"
    cp ${f} ${incl_dir}
  else
    echo "    ${f} -- ???"
  fi
done

echo "Copying libraries to directory ${lib_dir}"
for f in ${libraries} ; do
  if [ -f "${f}" ] ; then
    echo "    ${f} -- ok"
    cp ${f} ${lib_dir}
  else
    echo "    ${f} -- ???"
  fi
done

echo "Moving runtimes to directory ${bin_dir}"
for prog in ${runtimes}
do
  if [ -f "${prog}" ] ; then
    echo "    ${prog} -- ok"
    mv ${prog} ${bin_dir}
  else
    echo "    ${prog} -- ???"
  fi
done

exit 0
